@@ -1,21 +1,20 @@
-package Net::CLI::Interact;
-{
-  $Net::CLI::Interact::VERSION = '1.122020_002';
+package # hide from pause
+    Net::CLI::Interact::Meta::Attribute::Trait::Mediated;
+use Moose::Role;
+
+package # hide from pause
+    Moose::Meta::Attribute::Custom::Trait::Mediated;
+sub register_implementation {
+    return 'Net::CLI::Interact::Meta::Attribute::Trait::Mediated';
 }
 
-{
-    package # hide from pause
-        Net::CLI::Interact::Meta::Attribute::Trait::Mediated;
-    use Moose::Role;
-
-    package # hide from pause
-        Moose::Meta::Attribute::Custom::Trait::Mediated;
-    sub register_implementation {
-        return 'Net::CLI::Interact::Meta::Attribute::Trait::Mediated';
-    }
-}
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+package Net::CLI::Interact;
+BEGIN {
+  $Net::CLI::Interact::VERSION = '1.110890';
+}
+
 use Moose;
 with 'Net::CLI::Interact::Role::Engine';
 
@@ -26,7 +25,7 @@ has '__mediator_params' => (
     required => 1,
 );
 
-# takes the params hash and returns two hashes, the params
+# takes the params has and returns two hashes, the params
 # hash and a new hash of the current class's attribute slots
 sub _filter_my_attribute_list {
     my ($class, $params) = @_;
@@ -88,12 +87,7 @@ sub set_global_log_at {
     });
 }
 
-sub BUILD {
-    my $self = shift;
-    $self->set_global_log_at($self->log_at);
-    $self->logger->log('engine', 'notice',
-        sprintf "NCI loaded, version %s", ($Net::CLI::Interact::VERSION || 'devel'));
-}
+sub BUILD { my $self = shift; $self->set_global_log_at($self->log_at); }
 
 has 'phrasebook' => (
     is => 'ro',
@@ -111,19 +105,9 @@ sub _build_phrasebook {
     });
 }
 
-# does not really *change* the phrasebook, just reconfig and nuke
-sub set_phrasebook {
-    my ($self, $args) = @_;
-    return unless defined $args and ref $args eq ref {};
-    foreach my $k (keys %$args) {
-        $self->__mediator_params->{$k} = $args->{$k};
-    }
-    $self->clear_phrasebook;
-}
-
 has 'transport' => (
     is => 'ro',
-    isa => 'Net::CLI::Interact::Transport',
+    does => 'Net::CLI::Interact::Role::Transport',
     lazy_build => 1,
     traits => ['Mediated'],
 );
@@ -150,16 +134,11 @@ __END__
 
 =head1 NAME
 
-Net::CLI::Interact - Toolkit for CLI Automation
+Net::CLI::Interact::Meta::Attribute::Trait::Mediated - Toolkit for CLI Automation
 
 =head1 VERSION
 
-version 1.122020_002
-
-=head1 PURPOSE
-
-This module exists to support developers of applications and libraries which
-must interact with a command line interface.
+version 1.110890
 
 =head1 SYNOPSIS
 
@@ -209,20 +188,17 @@ Reuseable device command phrasebooks
 
 =back
 
-If you're a new user, please read the
-L<Tutorial|Net::CLI::Interact::Manual::Tutorial>. There's also a
-L<Cookbook|Net::CLI::Interact::Manual::Cookbook> and a L<Phrasebook
-Listing|Net::CLI::Interact::Manual::Phrasebook>. For a more complete worked
-example check out the L<Net::Appliance::Session> distribution, for which this
-module was written.
+=head1 PURPOSE
+
+This module exists to support developers of applications and libraries which
+must interact with a command line interface.
 
 =head1 INTERFACE
 
 =head2 new( \%options )
 
-Prepares a new session for you, but will not connect to any device. On
-Windows platforms, you B<must> download the C<plink.exe> program, and pass
-its location to the C<app> parameter. Other options are:
+Prepares a new session for you, but will not connect to any device. Options
+are:
 
 =over 4
 
@@ -230,14 +206,13 @@ its location to the C<app> parameter. Other options are:
 
 The family of device command phrasebooks to load. There is a built-in library
 within this module, or you can provide a search path to other libraries. See
-L<Net::CLI::Interact::Manual::Phrasebook> for further details.
+L<Net::CLI::Interact::Phrasebook> for further details.
 
 =item C<< transport => $backend >> (required)
 
 The name of the transport backend used for the session, which may be one of
-L<Telnet|Net::CLI::Interact::Transport::Telnet>,
-L<SSH|Net::CLI::Interact::Transport::SSH>, or
-L<Serial|Net::CLI::Interact::Transport::Serial>.
+L<Telnet|Net::CLI::Interact::Telnet>, L<SSH|Net::CLI::Interact::SSH>, or
+L<Serial|Net::CLI::Interact::Serial>.
 
 =item C<< connect_options => \%options >>
 
@@ -262,8 +237,8 @@ until there is a match with the current I<prompt>. The statement is executed
 verbatim on the device, with a newline appended.
 
 In scalar context the C<last_response> is returned (see below). In list
-context the gathered response is returned as a list of lines. In both cases
-your local platform's newline character will end all lines.
+context the gathered response is returned, only split into a list on the
+I<input record separator> (newline).
 
 =head2 macro( $name, \%options? )
 
@@ -272,24 +247,21 @@ from a Phrasebook. Options to control the output, including variables for
 substitution into the Macro, are passed in the C<%options> hash reference.
 
 In scalar context the C<last_response> is returned (see below). In list
-context the gathered response is returned as a list of lines. In both cases
-your local platform's newline character will end all lines.
+context the gathered response is returned, only split into a list on the
+I<input record separator> (newline).
 
 =head2 last_response
 
 Returns the gathered output after the most recent C<cmd> or C<macro>. In
 scalar context all data is returned. In list context the gathered response is
-returned as a list of lines. In both cases your local platform's newline
-character will end all lines.
+returned, only split into a list on the I<input record separator> (newline).
 
 =head2 transport
 
-Returns the L<Transport|Net::CLI::Interact::Transport> backend which was
+Returns the L<Transport|Net::CLI::Interact::Role::Transport> backend which was
 loaded based on the C<transport> option to C<new>. See the
-L<Telnet|Net::CLI::Interact::Transport::Telnet>,
-L<SSH|Net::CLI::Interact::Transport::SSH>, or
-L<Serial|Net::CLI::Interact::Transport::Serial> documentation for further
-details.
+L<Telnet|Net::CLI::Interact::Telnet>, L<SSH|Net::CLI::Interact::SSH>, or
+L<Serial|Net::CLI::Interact::Serial> documentation for further details.
 
 =head2 phrasebook
 
@@ -297,13 +269,6 @@ Returns the Phrasebook object which was loaded based on the C<personality>
 option given to C<new>. See L<Net::CLI::Interact::Phrasebook> for further
 details.
 
-=head2 set_phrasebook( \%options )
-
-Allows you to (re-)configure the loaded phrasebook, perhaps changing the
-personality or library, or other properties. The C<%options> Hash ref should
-be any parameters from the L<Phrasebook|Net::CLI::Interact::Phrasebook>
-module, but at a minimum must include a C<personality>.
-
 =head2 set_default_contination( $macro_name )
 
 Briefly, a Continuation handles the slurping of paged output from commands.
@@ -345,9 +310,9 @@ documentation for further details.
 
 All commands and macros are composed from their phrasebook definitions into
 L<Actions|Net::CLI::Interact::Action> and
-L<ActionSets|Net::CLI::Interact::ActionSet> (iterable sequences of Actions).
-See those modules' documentation for further details, in case you wish to
-introspect their structures.
+L<ActionSets|Net::CLI::Interact::ActionSet> (simply iterable sequences of
+Actions). See those modules' documentation for further details, in case you
+wish to introspect their structures.
 
 =head1 COMPOSITION
 
@@ -367,7 +332,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
