@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Action;
-{
-  $Net::CLI::Interact::Action::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Action::VERSION = '1.110890';
 }
 
 use Moose;
@@ -15,7 +15,7 @@ has 'type' => (
 
 has 'value' => (
     is => 'ro',
-    isa => 'Str|ArrayRef[RegexpRef]',
+    isa => 'Str|RegexpRef',
     required => 1,
 );
 
@@ -26,6 +26,14 @@ has 'no_ors' => (
     default => 0,
 );
 
+has 'is_lazy' => (
+    is => 'ro',
+    isa => 'Bool',
+    required => 0,
+    default => 0,
+    init_arg => 'lazy',
+);
+
 has 'continuation' => (
     is => 'rw',
     isa => 'Net::CLI::Interact::ActionSet',
@@ -54,12 +62,6 @@ has 'response_stash' => (
     required => 0,
 );
 
-has 'prompt_hit' => (
-    is => 'rw',
-    isa => 'RegexpRef',
-    required => 0,
-);
-
 sub BUILDARGS {
     my ($class, @rest) = @_;
     # accept single hash ref or naked hash
@@ -84,7 +86,7 @@ sub clone {
 # count the number of sprintf parameters used in the value
 sub num_params {
     my $self = shift;
-    return 0 if ref $self->value;
+    return 0 if ref $self->value eq ref qr//;
     # this tricksy little number comes from the Perl FAQ
     my $count = () = $self->value =~ m/(?<!%)%/g;
     return $count;
@@ -104,7 +106,7 @@ Net::CLI::Interact::Action - Sent data or matched response from connected device
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.110890
 
 =head1 DESCRIPTION
 
@@ -131,15 +133,19 @@ Denotes the kind of Action, which may be C<send> or C<match>.
 =head2 value
 
 In the case of C<send>, a String command to send to the device. In the case of
-C<match>, a regular expression reference to match response from the device. In
-special circumstances an array reference of regular expression references is
-also valid, and each will be checked for a match against the device response.
+C<match>, a regular expression reference to match response from the device.
 
 =head2 no_ors
 
-Only applies to the C<send> kind. Whether to skip appending the I<output
-record separator> (newline) to the C<send> command when sent to the connected
-device.
+Whether to append the I<output record separator> (newline) to the C<send>
+command when sent to the connected device.
+
+=head2 is_lazy
+
+Only applies to the C<match> kind, and records whether the user specified this
+Match as a regular expression reference, or the name of a Match defined
+elsewhere. In the latter case, it can trigger C<Net::CLI::Interact> to assume
+the Prompt value has permanently changed.
 
 =head2 continuation
 
@@ -173,12 +179,6 @@ the matched prompt which ended the action. This slot is used by the C<match>
 action as it slurps output, but the content is then transferred over to the
 partner C<send> in the ActionSet.
 
-=head2 prompt_hit
-
-When a command is successfully issued, the response is terminated by a prompt.
-However that prompt can be one of a list, defined in the Action. This slot
-records the regular expression from that list which was actually matched.
-
 =head2 clone
 
 Returns a new Action, which is a shallow clone of the existing one. All the
@@ -193,7 +193,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
