@@ -1,18 +1,12 @@
 package Net::CLI::Interact::ActionSet;
-{
-  $Net::CLI::Interact::ActionSet::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::ActionSet::VERSION = '1.110890';
 }
 
 use Moose;
 use Net::CLI::Interact::Action;
 with 'Net::CLI::Interact::Role::Iterator';
 
-use Moose::Util::TypeConstraints;
-subtype 'Net::CLI::Interact::ActionSet::CurrentMatchType'
-    => as 'Maybe[ArrayRef[RegexpRef]]';
-coerce 'Net::CLI::Interact::ActionSet::CurrentMatchType'
-    => from 'RegexpRef' => via { [$_] };
-
 has default_continuation => (
     is => 'rw',
     isa => 'Maybe[Net::CLI::Interact::ActionSet]',
@@ -21,9 +15,8 @@ has default_continuation => (
 
 has current_match => (
     is => 'rw',
-    isa => 'Net::CLI::Interact::ActionSet::CurrentMatchType',
+    isa => 'Maybe[RegexpRef]',
     required => 0,
-    coerce => 1,
 );
 
 has '+_sequence' => (
@@ -32,7 +25,6 @@ has '+_sequence' => (
 
 sub BUILDARGS {
     my ($class, @rest) = @_;
-
     # accept single hash ref or naked hash
     my $params = (ref $rest[0] eq ref {} and scalar @rest == 1 ? $rest[0] : {@rest});
 
@@ -164,8 +156,8 @@ sub _marshall_responses {
         next unless $match->type eq 'match';
 
         # remove echoed command from the beginning
-        my $cmd = quotemeta( $send->value );
-        (my $output = $match->response_stash) =~ s/^$cmd\s*//;
+        my $cmd = $send->value;
+        (my $output = $match->response_stash) =~ s/^$cmd\s+//;
         $send->response($output);
     }
 }
@@ -184,7 +176,7 @@ Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.110890
 
 =head1 DESCRIPTION
 
@@ -236,7 +228,7 @@ with the Action(s) according to how many are required.
 
 =head2 register_callback
 
-Allows the L<Transport|Net::CLI::Interact::Transport> to be registered
+Allows the L<Transport|Net::CLI::Interact::Role::Transport> to be registered
 such that when the ActionSet is executed, commands are sent to the registered
 callback subroutine. May be called more than once, and on execution each of
 the callbacks will be run, in turn and in order.
@@ -247,16 +239,14 @@ The business end of this class, where the sequence of Actions is prepared for
 execution and then control passed to the Transport. This process is split into
 a number of phases:
 
-=over 4
-
-=item Pad C<send> with C<match>
+=head3 Pad C<send> with C<match>
 
 The Phrasebook allows missing out of the Match statements between Send
 statements, when they are expected to be the same as the C<current_match>.
 This phase inserts Match statements to restore a complete ActionSet
 definition.
 
-=item Forward C<continuation> to C<match>
+=head3 Forward C<continuation> to C<match>
 
 In the Phrasebook a user defines a Continuation (C<match>, then C<send>)
 following a Send statement (because it deals with the response to the sent
@@ -268,20 +258,18 @@ Match statements in the ActionSet. It also performs a similar action using the
 C<default_continuation> if one is set and there's no existing Continuation
 configured.
 
-=item Callback(s)
+=head3 Callback(s)
 
-Here the registered callbacks are executed (i.e. data is sent to the
+Here the registered callbacks are executed (i.e. data is setnt to the
 Transport).
 
-=item Marshall Responses
+=head3 Marshall Responses
 
 Finally, responses which are stashed in the Match Actions are copied back to
 the Send actions, as more logically they are responses to commands sent. The
 ActionSet is now ready for access to retrieve the C<last_response> from the
 device.
 
-=back
-
 =head1 COMPOSITION
 
 See the following for further interface details:
@@ -300,7 +288,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
