@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Phrasebook;
-{
-  $Net::CLI::Interact::Phrasebook::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Phrasebook::VERSION = '1.110890';
 }
 
 use Moose;
@@ -30,12 +30,11 @@ sub _build_library {
     my (undef, $directory, undef) = fileparse(
         $INC{ 'Net/CLI/Interact.pm' }
     );
-    return [ Path::Class::Dir->new($directory)
-        ->subdir("Interact", "phrasebook")->stringify ];
+    return ["${directory}Interact/phrasebook"];
 }
 
 has 'add_library' => (
-    is => 'rw',
+    is => 'ro',
     isa => 'Str|ArrayRef[Str]',
     default => sub { [] },
     required => 0,
@@ -50,19 +49,12 @@ has '_prompt' => (
 
 sub prompt {
     my ($self, $name) = @_;
-    confess "unknown prompt [$name]" unless $self->has_prompt($name);
+    confess "missing prompt argument!" unless defined $name;
+    confess "unknown prompt [$name]"
+        unless length $name and exists $self->_prompt->{$name};
     return $self->_prompt->{$name};
 }
 
-sub prompt_names { return keys %{ (shift)->_prompt } }
-
-sub has_prompt {
-    my ($self, $name) = @_;
-    confess "missing prompt name!"
-        unless defined $name and length $name;
-    return exists $self->_prompt->{$name};
-}
-
 has '_macro' => (
     is => 'ro',
     isa => 'HashRef[Net::CLI::Interact::ActionSet]',
@@ -72,59 +64,53 @@ has '_macro' => (
 
 sub macro {
     my ($self, $name) = @_;
-    confess "unknown macro [$name]" unless $self->has_macro($name);
+    confess "missing macro argument!" unless defined $name;
+    confess "unknown macro [$name]"
+        unless length $name and exists $self->_macro->{$name};
     return $self->_macro->{$name};
 }
 
-sub macro_names { return keys %{ (shift)->_macro } }
-
-sub has_macro {
-    my ($self, $name) = @_;
-    confess "missing macro name!"
-        unless defined $name and length $name;
-    return exists $self->_macro->{$name};
-}
-
-# matches which are prompt names are resolved to RegexpRefs
-# and regexp provided by the user are inflated into RegexpRefs
-sub _resolve_matches {
-    my ($self, $actions) = @_;
-
-    foreach my $a (@$actions) {
-        next unless $a->{type} eq 'match';
-        next unless ref $a->{value} eq ref [];
-
-        my @newvals = ();
-        foreach my $v (@{ $a->{value} }) {
-            if ($v =~ m{^/} and $v =~ m{/$}) {
-                $v =~ s{^/}{}; $v =~ s{/$}{};
-                push @newvals, qr/$v/;
-            }
-            else {
-                push @newvals, @{ $self->prompt($v)->first->value };
-            }
-        }
-
-        $a->{value} = \@newvals;
-    }
-
-    return $actions;
-}
-
 # inflate the hashref into action objects
 sub _bake {
     my ($self, $data) = @_;
-
     return unless ref $data eq ref {} and keys %$data;
-    $self->logger->log('phrasebook', 'debug', 'storing', $data->{type}, $data->{name});
+    $self->logger->log('phrasebook', 'debug', 'storing type', $data->{type}, 'with name', $data->{name});
 
     my $slot = '_'. lc $data->{type};
     $self->$slot->{$data->{name}}
         = Net::CLI::Interact::ActionSet->new({
-            actions => $self->_resolve_matches($data->{actions})
+            actions => $data->{actions}
         });
 }
 
+# matches which are prompt names are resolved to RegexpRefs
+sub _resolve_lazy_matches {
+    my $self = shift;
+
+    foreach my $name (keys %{$self->_macro}) {
+        my $set = $self->macro($name);
+        my $new_set = [];
+
+        $set->reset;
+        while ($set->has_next) {
+            my $item = $set->next;
+            if ($item->is_lazy) {
+                push @$new_set, $item->clone({ value =>
+                    $self->prompt($item->value)->first->value
+                });
+            }
+            else {
+                push @$new_set, $item;
+            }
+        }
+
+        # direct access to macros hash
+        $self->_macro->{$name} = Net::CLI::Interact::ActionSet->new({
+            actions => $new_set
+        });
+    }
+}
+
 sub BUILD {
     my $self = shift;
     $self->load_phrasebooks;
@@ -154,39 +140,34 @@ sub load_phrasebooks {
                 next;
             }
 
-            if (m{^\s+send\s+(.+)$}) {
-                my $value = $1;
+            if (m{^\s+(send(?:_no_ors)?)\s+(.+)$}) {
+                my ($type, $value) = ($1, $2);
                 $value =~ s/^["']//; $value =~ s/["']$//;
                 push @{ $data->{actions} }, {
                     type => 'send', value => $value,
+                    no_ors => ($type eq 'send_no_ors')
                 };
                 next;
             }
 
-            if (m{^\s+put\s+(.+)$}) {
-                my $value = $1;
-                $value =~ s/^["']//; $value =~ s/["']$//;
-                push @{ $data->{actions} }, {
-                    type => 'send', value => $value, no_ors => 1,
-                };
+            if (m{^\s+match\s+prompt\s+(.+)\s*$}) {
+                push @{ $data->{actions} },
+                    {type => 'match', value => $1, lazy => 1};
                 next;
             }
 
-            if (m{^\s+match\s+(.+)\s*$}) {
-                my @vals = split m/\s+or\s+/, $1;
-                if (scalar @vals) {
-                    push @{ $data->{actions} },
-                        {type => 'match', value => \@vals};
-                    next;
-                }
+            if (m{^\s+match\s+/(.+)/\s*$}) {
+                push @{ $data->{actions} },
+                    {type => 'match', value => qr/$1/};
+                next;
             }
 
             if (m{^\s+follow\s+/(.+)/\s+with\s+(.+)\s*$}) {
                 my ($match, $send) = ($1, $2);
                 $send =~ s/^["']//; $send =~ s/["']$//;
                 $data->{actions}->[-1]->{continuation} = [
-                    {type => 'match', value => [qr/$match/]},
-                    {type => 'send',  value => eval "qq{$send}", no_ors => 1}
+                    {type => 'match', value => qr/$match/},
+                    {type => 'send',  value => $send, no_ors => 1}
                 ];
                 next;
             }
@@ -195,27 +176,17 @@ sub load_phrasebooks {
         }
         # last entry in the file needs baking
         $self->_bake($data);
-        $data = {};
     }
+
+    $self->_resolve_lazy_matches;
 }
 
 # finds the path of Phrasebooks within the Library leading to Personality
 use Path::Class;
 sub _find_phrasebooks {
     my $self = shift;
-    my @libs = (ref $self->library ? @{$self->library} : ($self->library));
-    my @alib = (ref $self->add_library ? @{$self->add_library} : ($self->add_library));
-
-    my @phrasebooks =
-        ( $self->_walk_find_files(@libs), $self->_walk_find_files(@alib) );
-
-    confess (sprintf "Personality [%s] contains no phrasebook files!\n",
-            $self->personality) unless scalar @phrasebooks;
-    return @phrasebooks;
-}
-
-sub _walk_find_files {
-    my ($self, @libs) = @_;
+    my @libs = (ref $self->add_library ? @{$self->add_library} : ($self->add_library));
+    push @libs, (ref $self->library ? @{$self->library} : ($self->library));
 
     my $target = undef;
     foreach my $l (@libs) {
@@ -225,18 +196,22 @@ sub _walk_find_files {
         });
         last if $target;
     }
-    return () unless defined $target;
+    confess (sprintf "couldn't find Personality '%s' within your Library\n",
+            $self->personality) unless $target;
 
-    my @files = ();
-    my $root = Path::Class::Dir->new($target->is_absolute ? '' : ());
+    my @phrasebooks = ();
+    my $root = Path::Class::Dir->new('/');
     foreach my $part ( $target->dir_list ) {
         $root = $root->subdir($part);
         next if scalar grep { $root->subsumes($_) } @libs;
-        push @files,
+        push @phrasebooks,
             sort {$a->basename cmp $b->basename}
             grep { not $_->is_dir } $root->children(no_hidden => 1);
     }
-    return @files;
+
+    confess (sprintf "Personality [%s] contains no content!\n",
+            $self->personality) unless scalar @phrasebooks;
+    return @phrasebooks;
 }
 
 1;
@@ -253,7 +228,7 @@ Net::CLI::Interact::Phrasebook - Load command phrasebooks from a Library
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.110890
 
 =head1 DESCRIPTION
 
@@ -271,8 +246,8 @@ Entries in the phrasebook will be one of the following types:
 
 =item Prompt
 
-Named regular expressions that match the content of a single line of text in
-the output returned from a connected device. They are a demarcation between
+Named regular expressions that will match the content of a single line of text
+in the output returned from a connected device. They are a demarcation between
 commands sent and responses returned.
 
 =item Macro
@@ -283,10 +258,9 @@ explained below.
 
 =back
 
-The named regular expressions used in Prompts and Macros are known as I<Match>
+The named regular expressions used in Prompts and Macros are known as Match
 statements. The command statements in Macros which are sent to the device are
-known as I<Send> statements. That is, Prompts and Macros are built from one or
-more Match and Send statements.
+known as Send statements.
 
 Each Send or Match statement becomes an instance of the
 L<Net::CLI::Interact::Action> class. These are built up into Prompts and
@@ -305,19 +279,18 @@ For example:
 
 Entries in C<file3> sharing a name with any entries from C<file1> or C<file2>
 will take precedence. Those in C<file2> will also override entries in
-C<file1>, because asciibetical sorting places the files in that order, and
-later definitions with the same name and type override earlier ones.
+C<file1>, because asciibetical sorting places the files in that order.
 
 When this module is loaded, a I<personality> key is required. This locates a
 directory on disk, and then the files in that directory and all its ancestors
-in the hierarchy are loaded. The directory root is specified by two I<Library>
+in the hierarchy are loaded. The directory root is specified by two Library
 options.
 
 =head1 INTERFACE
 
 =head2 new( \%options )
 
-This takes the following options, and returns a loaded phrasebook object:
+This takes the following options, and returns a baked phrasebook:
 
 =over 4
 
@@ -349,28 +322,12 @@ Returns the Prompt associated to the given C<$name>, or throws an exception if
 no such prompt can be found. The returned object is an instance of
 L<Net::CLI::Interact::ActionSet>.
 
-=head2 has_prompt( $name )
-
-Returns true if a prompt of the given C<$name> exists in the loaded phrasebooks.
-
-=head2 prompt_names
-
-Returns a list of the names of the current loaded Prompts.
-
 =head2 macro( $name )
 
 Returns the Macro associated to the given C<$name>, or throws an exception if
 no such macro can be found. The returned object is an instance of
 L<Net::CLI::Interact::ActionSet>.
 
-=head2 has_macro( $name )
-
-Returns true if a macro of the given C<$name> exists in the loaded phrasebooks.
-
-=head2 macro_names
-
-Returns a list of the names of the current loaded Macros.
-
 =head1 PHRASEBOOK FORMAT
 
 =head2 Prompt
@@ -392,12 +349,11 @@ include them within.
 
 The Prompt is used to find out when the connected CLI has emitted all of the
 response to a command. Try to make the Prompt as specific as possible,
-including line-end anchors. Remember that it will be matched against one line
-of text, only.
+including line-end anchors.
 
 =head2 Macro
 
-In general, Macros are alternating sequences of commands to send to the
+In general Macros are alternating sequences of commands to send to the
 connected CLI, and regular expressions to match the end of the returned
 response. Macros are useful for issueing commands which have intermediate
 prompts, or confirmation steps. They also support the I<slurping> of
@@ -414,10 +370,10 @@ which must be a valid Perl identifier (letters, numbers, underscores only).
 
 On the immediately following line is the keyword C<send> followed by a space
 and then any text up until the end of the line, and if you want to include
-whitespace at the beginning or end of the command, use quotes. This text is
-sent to the connected CLI as a single command statement. The next line
-contains the keyword C<match> followed by the Prompt (regular expression)
-which will terminate gathering of returned output from the sent command.
+whitespace at the beginning or end, use quotes. This text is sent to the
+connected CLI as a single command statement. The next line contains the
+keyword C<match> followed by the Prompt (regular expression) which will
+terminate gathering of returned output from the sent command.
 
 Macros support the following features:
 
@@ -449,7 +405,7 @@ statement when it's the same as the current Prompt.
 
 =item Format Interpolation
 
-Each C<send> statement is in fact run through Perl's C<sprintf> command, so
+Each <send> statement is in fact run through Perl's C<sprintf> command, so
 variables may be interpolated into the statement using standard C<"%"> fields.
 For example:
 
@@ -473,15 +429,10 @@ instead:
      send enable
      match /[Pp]assword: ?$/
      send %s
-     match priv_exec
+     match prompt priv_exec
 
-As you can see, in the case of the last Match, we have the keyword C<match>
-followed by the name of a defined Prompt. To match multiple defined Prompts
-use this syntax (with as many named references as you like):
-
- macro to_privileged
-     send enable
-     match username_prompt or priv_exec
+As you can see, in the case of the last Match, we have the keywords C<match
+prompt> followed by the name of a defined Prompt.
 
 =item Continuations
 
@@ -502,8 +453,7 @@ the line. If you need to enclose whitespace use quotes, as in the example.
 
 The module will send the continuation text and gobble the matched prompt from
 the emitted output so you only have one complete piece of text returned, even
-if split over many pages. The sent text can contain metacharacters such as
-C<\n> for a newline.
+if split over many pages.
 
 Note that in the above example the C<follow> statement should be seen as an
 extension of the C<send> statement. There is still an implicit Match prompt
@@ -512,9 +462,9 @@ added at the end of this Macro, as per Automatic Matching, above.
 =item Line Endings
 
 Normally all sent command statements are appended with a newline (or the value
-of C<ors>, if set). To suppress that feature, use the keyword C<put> instead
-of C<send>. However this does not prevent the Format Interpolation via
-C<sprintf> as described above (simply use C<"%%"> to get a literal C<"%">).
+of C<ors>, if set). To suppress that feature, use the keyword C<send_no_ors>
+instead of C<send>. However this does not prevent the Format Interpolation via
+C<sprintf> as described above (which would be necessary: simply use C<"%%">).
 
 =back
 
@@ -524,7 +474,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
