@@ -1,55 +1,40 @@
-package Net::CLI::Interact::Role::Engine;
-{
-  $Net::CLI::Interact::Role::Engine::VERSION = '1.122020_002';
+package # hide from pause
+    Net::CLI::Interact::Role::Engine::ExecuteOptions;
+use Moose;
+
+has 'no_ors' => (
+    is => 'ro',
+    isa => 'Bool',
+    default => 0,
+    required => 0,
+);
+
+has 'params' => (
+    is => 'ro',
+    isa => 'ArrayRef[Str]',
+    auto_deref => 1,
+    required => 0,
+);
+
+has 'timeout' => (
+    is => 'ro',
+    isa => 'Int',
+    required => 0,
+);
+
+sub BUILDARGS {
+    my ($class, @params) = @_;
+    return {} unless scalar @params > 0 and defined $params[0];
+    return { @params };
 }
 
-{
-    package # hide from pause
-        Net::CLI::Interact::Role::Engine::ExecuteOptions;
-    use Moose;
-    use Moose::Util::TypeConstraints;
-
-    subtype 'Net::CLI::Interact::Role::Engine::ExecuteOptions::MatchType'
-        => as 'ArrayRef[RegexpRef|Str]';
-    coerce 'Net::CLI::Interact::Role::Engine::ExecuteOptions::MatchType'
-        => from 'Str|RegexpRef' => via { [$_] };
-
-    has 'no_ors' => (
-        is => 'ro',
-        isa => 'Bool',
-        default => 0,
-        required => 0,
-    );
-
-    has 'params' => (
-        is => 'ro',
-        isa => 'ArrayRef[Str]',
-        auto_deref => 1,
-        required => 0,
-    );
-
-    has 'timeout' => (
-        is => 'ro',
-        isa => subtype( 'Int' => where { $_ > 0 } ),
-        required => 0,
-    );
-
-    has 'match' => (
-        is => 'rw',
-        isa => 'Net::CLI::Interact::Role::Engine::ExecuteOptions::MatchType',
-        predicate => 'has_match',
-        required => 0,
-        coerce => 1,
-    );
-
-    sub BUILDARGS {
-        my ($class, @params) = @_;
-        return {} unless scalar @params > 0 and ref $params[0] eq ref {};
-        return $params[0];
-    }
-}
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+package Net::CLI::Interact::Role::Engine;
+BEGIN {
+  $Net::CLI::Interact::Role::Engine::VERSION = '1.110890';
+}
+
 use Moose::Role;
 with 'Net::CLI::Interact::Role::Prompt';
 
@@ -64,10 +49,9 @@ has 'last_actionset' => (
 
 sub last_response {
     my $self = shift;
-    my $irs_re = $self->transport->irs_re;
-    (my $resp = $self->last_actionset->item_at(-2)->response) =~ s/$irs_re/\n/g;
+    my $resp = $self->last_actionset->item_at(-2)->response;
     return (wantarray
-        ? (map {$_ .= "\n"} split m/\n/, $resp)
+        ? (split $self->transport->irs, $resp)
         : $resp);
 }
 
@@ -94,24 +78,6 @@ sub cmd {
 
     $self->logger->log('engine', 'notice', 'running command', $command);
 
-    if ($options->has_match) {
-        # convert prompt name(s) from name into regexpref, or die
-        $options->match([
-            map { ref $_ eq ref '' ? @{ $self->phrasebook->prompt($_)->first->value }
-                                   : $_ }
-                @{ $options->match }
-        ]);
-
-        $self->logger->log('engine', 'info', 'to match',
-            (ref $options->match eq ref [] ? (join '|', @{$options->match})
-                                           : $options->match));
-    }
-
-    # command will be run through sprintf but without any params
-    # so convert any embedded % to literal %
-    ($command =~ s/%/%%/g) &&
-        $self->logger->log('engine', 'debug', 'command expanded to:', $command);
-
     return $self->_execute_actions(
         $options,
         Net::CLI::Interact::Action->new({
@@ -142,14 +108,14 @@ sub _execute_actions {
     $self->logger->log('engine', 'notice', 'executing actions');
 
     # make connection on transport if not yet done
-    $self->transport->init if not $self->transport->connect_ready;
+    $self->transport->connect if not $self->transport->done_connect;
 
     # user can install a prompt, call find_prompt, or let us trigger that
-    $self->find_prompt(1) if not ($self->prompt_re || $self->last_actionset);
+    $self->find_prompt if not ($self->prompt_re || $self->last_actionset);
 
     my $set = Net::CLI::Interact::ActionSet->new({
         actions => [@actions],
-        current_match => ($options->match || $self->prompt_re || $self->last_prompt_re),
+        current_match => ($self->prompt_re || $self->last_prompt_as_match),
         default_continuation => $self->default_continuation,
     });
     $set->register_callback(sub { $self->transport->do_action(@_) });
@@ -162,12 +128,15 @@ sub _execute_actions {
     $self->transport->timeout($timeout_bak);
     $self->last_actionset($set);
 
-    $self->logger->log('prompt', 'info',
-        sprintf 'setting new prompt to %s',
-            $self->last_actionset->last->prompt_hit || '<none>');
-    $self->_prompt( $self->last_actionset->last->prompt_hit );
+    # if user used a match ref then we assume new prompt value
+    if ($self->last_actionset->last->is_lazy) {
+        $self->logger->log('prompt', 'info',
+            'last match was a prompt reference, setting new prompt');
+        # direct access to the slot
+        $self->_prompt($self->last_actionset->last->value);
+    }
 
-    return $self->last_response; # context sensitive
+    return $self->last_response; # context sensitive
 }
 
 1;
@@ -180,11 +149,11 @@ __END__
 
 =head1 NAME
 
-Net::CLI::Interact::Role::Engine - Statement execution engine
+Net::CLI::Interact::Role::Engine::ExecuteOptions - Statement execution engine
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.110890
 
 =head1 DESCRIPTION
 
@@ -206,27 +175,20 @@ The following options are supported:
 
 =item C<< timeout => $seconds >> (optional)
 
-Sets a value of C<timeout> for the
-L<Transport|Net::CLI::Interact::Transport> local to this call of C<cmd>, that
-overrides whatever is set in the Transport, or the default of 10 seconds.
+Sets a value of C<timeout> for the L<Transport|Net::CLI::Interact::Transport>
+local to this call of C<cmd>, that overrides whatever is set in the Transport,
+or the default of 10 seconds.
 
 =item C<< no_ors => 1 >> (optional)
 
 When passed a true value, a newline character (in fact the value of C<ors>)
 will not be appended to the statement sent to the device.
 
-=item C<< match => $name | $regexpref | \@names_and_regexprefs >> (optional)
-
-Allows this command (only) to complete with a custom match, which must be one
-or more of either the name of a loaded phrasebook Prompt or your own regular
-expression reference (C<< qr// >>). The module updates the current prompt to
-be the same value on a successful match.
-
 =back
 
 In scalar context the C<last_response> is returned (see below). In list
-context the gathered response is returned as a list of lines. In both cases
-your local platform's newline character will end all lines.
+context the gathered response is returned, only split into a list on the
+I<input record separator> (newline).
 
 =head2 macro( $macro_name, \%options? )
 
@@ -249,9 +211,9 @@ if there are insufficient parameters.
 
 =item C<< timeout => $seconds >> (optional)
 
-Sets a value of C<timeout> for the
-L<Transport|Net::CLI::Interact::Transport> local to this call of C<macro>,
-that overrides whatever is set in the Transport, or the default of 10 seconds.
+Sets a value of C<timeout> for the L<Transport|Net::CLI::Interact::Transport>
+local to this call of C<macro>, that overrides whatever is set in the
+Transport, or the default of 10 seconds.
 
 =back
 
@@ -261,18 +223,18 @@ value of C<timeout>, which controls how long the module waits for matching
 output.
 
 In scalar context the C<last_response> is returned (see below). In list
-context the gathered response is returned as a list of lines. In both cases
-your local platform's newline character will end all lines.
+context the gathered response is returned, only split into a list on the
+I<input record separator> (newline).
 
 =head2 last_response
 
-Returns the gathered output after issuing the last recent C<send> command
+Returns the gathered output after issueing the last recent C<send> command
 within the most recent C<cmd> or C<prompt>. That is, you get the output from
 the last command sent to the connected device.
 
 In scalar context all data is returned. In list context the gathered response
-is returned as a list of lines. In both cases your local platform's newline
-character will end all lines.
+is returned, only split into a list on the I<input record separator>
+(newline).
 
 =head2 last_actionset
 
@@ -304,7 +266,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
