@@ -1,11 +1,10 @@
 package Net::CLI::Interact::Role::Prompt;
-{
-  $Net::CLI::Interact::Role::Prompt::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Role::Prompt::VERSION = '1.110890';
 }
 
 use Moose::Role;
 use Net::CLI::Interact::ActionSet;
-with 'Net::CLI::Interact::Role::FindMatch';
 
 has 'wake_up' => (
     is => 'rw',
@@ -20,7 +19,6 @@ has '_prompt' => (
     isa => 'Maybe[RegexpRef]',
     required => 0,
     reader => 'prompt_re',
-    predicate => 'has_set_prompt',
     clearer => 'unset_prompt',
     trigger => sub {
         (shift)->logger->log('prompt', 'info', 'prompt has been set to', (shift));
@@ -28,8 +26,10 @@ has '_prompt' => (
 );
 
 sub set_prompt {
-    my ($self, $name) = @_;
-    $self->_prompt( $self->phrasebook->prompt($name)->first->value->[0] );
+    my ($self, $prompt) = @_;
+    confess "unknown prompt: [$prompt]"
+        unless eval { $self->phrasebook->prompt($prompt) };
+    $self->_prompt( $self->phrasebook->prompt($prompt)->first->value );
 }
 
 sub last_prompt {
@@ -37,36 +37,24 @@ sub last_prompt {
     return $self->last_actionset->item_at(-1)->response;
 }
 
-sub last_prompt_re {
-    my $self = shift;
-    my $prompt = $self->last_prompt;
+sub last_prompt_as_match {
+    my $prompt = (shift)->last_prompt;
     return qr/^\Q$prompt\E$/;
 }
 
-sub prompt_looks_like {
-    my ($self, $name) = @_;
-    return $self->find_match(
-        $self->last_prompt, $self->phrasebook->prompt($name)->first->value
-    );
-}
-
 # pump until any of the prompts matches the output buffer
 sub find_prompt {
-    my ($self, $wake_up) = @_;
+    my ($self, $tries) = @_;
     $self->logger->log('prompt', 'notice', 'finding prompt');
 
     # make connection on transport if not yet done
-    $self->transport->init if not $self->transport->connect_ready;
+    $self->transport->connect if not $self->transport->done_connect;
 
     eval {
-        PUMPING: while (1) {
-            $self->transport->pump;
-            $self->logger->log('dump', 'debug', "SEEN:\n". $self->transport->buffer);
-            foreach my $prompt ($self->phrasebook->prompt_names) {
+        while ($self->transport->harness->pump) {
+            foreach my $prompt (keys %{ $self->phrasebook->prompt }) {
                 # prompts consist of only one match action
-                if ($self->find_match(
-                        $self->transport->buffer,
-                        $self->phrasebook->prompt($prompt)->first->value)) {
+                if ($self->transport->out =~ $self->phrasebook->prompt($prompt)->first->value) {
                     $self->logger->log('prompt', 'info', "hit, matches prompt $prompt");
                     $self->last_actionset(
                         Net::CLI::Interact::ActionSet->new({ actions => [
@@ -76,38 +64,17 @@ sub find_prompt {
                         ] })
                     );
                     $self->set_prompt($prompt);
-                    last PUMPING;
+                    return;
                 }
                 $self->logger->log('prompt', 'debug', "nope, doesn't (yet) match $prompt");
             }
-            $self->logger->log('prompt', 'debug', 'no match so far, more data?');
         }
     };
-
-    if ($@ and $self->has_wake_up and $wake_up) {
-        $self->logger->log('prompt', 'info',
-            "failed: [$@], sending WAKE_UP and trying again");
-
-        eval {
-            $self->transport->put( $self->wake_up );
-            $self->find_prompt(--$wake_up);
-        };
-        if ($@) {
-            # really died, so this time bail out - with possible transport err
-            my $output = $self->transport->flush;
-            $self->transport->disconnect;
-            die $output;
-        }
-    }
-    else {
-        if (not $self->has_set_prompt) {
-            # trouble... we were asked to find a prompt but failed :-(
-            $self->logger->log('prompt', 'critical', 'failed to find prompt! wrong phrasebook?');
-            # bail out with what we have...
-            my $output = $self->transport->flush;
-            $self->transport->disconnect;
-            die $output;
-        }
+    # default call from user, $tries is zero, so run once more and inc tries
+    if ($@ and $self->has_wake_up and $tries) {
+        $self->logger->log('prompt', 'info', 'timeout, sending WAKE_UP and trying again');
+        $self->transport->send( $self->wake_up );
+        $self->find_prompt;
     }
 }
 
@@ -125,7 +92,7 @@ Net::CLI::Interact::Role::Prompt - Command-line prompt management
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.110890
 
 =head1 DESCRIPTION
 
@@ -135,10 +102,6 @@ idea is that most CLI have a prompt where you issue commands, and are returned
 some output which this module gathers. The prompt is a demarcation between
 each command and its response data.
 
-Note that although we "keep track" of the prompt, Net::CLI::Interact is not a
-state machine, and the choice of command issued to the connected device bears
-no relation to the current (or last matched) prompt.
-
 =head1 INTERFACE
 
 =head2 set_prompt( $prompt_name )
@@ -149,8 +112,8 @@ CLI session. This allows a sequence of commands to be sent which share the
 same Prompt.
 
 The name you pass in is looked up in the loaded Phrasebook and the entry's
-regular expression stored internally. An exception is thrown if the named
-Prompt is not known.
+regular expression stored in the C<prompt> slot. An exception is thrown if the
+named Prompt is not known.
 
 Typically you would either refer to a Prompt in a Macro, or set the prompt you
 are expecting once for a sequence of commands in a particular CLI context.
@@ -160,9 +123,9 @@ explicit named Prompt at the end, we can assume the user is indicating some
 change of context. Therefore the C<prompt> is I<automatically updated> on such
 occasions to have the regular expression from that named Prompt.
 
-=head2 prompt_re
+=head2 prompt
 
-Returns the current Prompt in the form of a regular expression reference. The
+Returns the current Prompt, which is a regular expression reference. The
 Prompt is used as a default to catch the end of command response output, when
 a Macro has not been set up with explicit Prompt matching.
 
@@ -176,19 +139,10 @@ is that the module will automatically set the Prompt for itself based on the
 last line of output received from the connected CLI. Do not use this option
 unless you know what you are doing.
 
-=head2 has_set_prompt
-
-Returns True if there is currently a Prompt set, otherwise returns False.
-
-=head2 prompt_looks_like( $name )
-
-Returns True if the current prompt matches the given named prompt. This is
-useful when you wish to make a more specific check on the current prompt.
-
 =head2 find_prompt( $wake_up? )
 
 A helper method that consumes output from the connected CLI session until a
-line matches any one of the named Prompts in the loaded Phrasebook, at which
+line matches one of the named Prompts in the loaded Phrasebooks, at which
 point no more output is consumed. As a consequence the C<prompt> will be set
 (see above).
 
@@ -206,16 +160,16 @@ disable this behaviour, pass a I<false> value into this method.
 
 =head2 wake_up
 
-Text sent to a device within the C<find_prompt> method if no output has so far
-matched any known named Prompt. Default is the value of the I<output record
-separator> from the L<Transport|Net::CLI::Interact::Transport> (one newline).
+Data sent to a device within C<find_prompt> if no output has so far matched
+any known named Prompt. Default is the value of the I<output record separator>
+from the L<Transport|Net::CLI::Interact::Transport> (newline).
 
 =head2 last_prompt
 
 Returns the Prompt which most recently was matched and terminated gathering of
 output from the connected CLI. This is a simple text string.
 
-=head2 last_prompt_re
+=head2 last_prompt_as_match
 
 Returns the text which was most recently matched and terminated gathering of
 output from the connected CLI, as a quote-escaped regular expression with line
@@ -227,7 +181,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
